Learn R Programming

glmmEP (version 1.0-3.1)

summary.glmmEP: Inferential summary for a generalized linear mixed model with expectation propagation fitting.

Description

Produces a table containing approximated maximum likelihood estimates and corresponding confidence interval limits for the fixed effect parameters and random effects standard deviation and correlation parameters.

Usage

# S3 method for glmmEP
summary(object,...)

Arguments

object

A glmmEP() fit object.

...

Place-holder for additional arguments.

Examples

Run this code
# NOT RUN {
dataObj <- glmmSimData(seed=54321)
y <- dataObj$y  
Xfixed <- dataObj$Xfixed
Xrandom <- dataObj$Xrandom  
idNum <- dataObj$idNum
# }
# NOT RUN {
fitSimData <- glmmEP(y,Xfixed,Xrandom,idNum)
summary(fitSimData)
# }

Run the code above in your browser using DataLab